#include <SPI.h>
#include <MFRC522.h>     // Reference library

#define RST_PIN      9        // Card reader reset pin
#define SS_PIN       10        // Chip selection pin

struct RFIDTag {    // Definition structure
   byte uid[4];
   char *name;
};

struct RFIDTag tags[] = {  // Initialization structure data
   {{0xF5,0x45,0x48,0xE7}, "ALSELECTRO"},
   {{0xE5,0x25,0x28,0xB7}, "myTag_2"},
   };

byte totalTags = sizeof(tags) / sizeof(RFIDTag);

MFRC522 mfrc522(SS_PIN, RST_PIN);  // Create MFRC522 object

void setup() {
  Serial.begin(9600);
  Serial.println();
  Serial.println("RFID reader is ready!");

  SPI.begin();
  mfrc522.PCD_Init();   //Initialize the MFRC522 card reader module
}

void loop() {
    // Confirm if there is a new card
    if (mfrc522.PICC_IsNewCardPresent() && mfrc522.PICC_ReadCardSerial()) {
      byte *id = mfrc522.uid.uidByte;   // Get the UID of the card
      byte idSize = mfrc522.uid.size;   // Get the length of the UID
      bool foundTag = false;            // Whether to find the label in the record, the default is "No".
      
      for (byte i=0; i<totalTags; i++) {
        if (memcmp(tags[i].uid, id, idSize) == 0) {
          Serial.println(tags[i].name);  //Display the name of the label
          foundTag = true;  // Set to "Find the label!"
          break;            // Exit for loop
        }
      }

      if (!foundTag) {    // If the label is scanned outside the record, it is displayed"Wrong card!"。
        Serial.println("Wrong card!");
      }

      mfrc522.PICC_HaltA();  // Put the card into stop mode   
    } 
}
